@@ -32,7 +32,7 @@ struct ArrayColReader
     long * types;
     long num_types;
 
-    parsed_t * missing_vals;
+    _ParsedT * missing_vals;
 
     long max_elems;
 
@@ -80,15 +80,15 @@ array_col_reader_dealloc(ArrayColReader * self)
     PyObject_GC_Del(self);
 }
 
-static parsed_t *
+static _ParsedT *
 array_col_reader_parse_missing_vals(PyObject * iterator, long num_types, bool & err)
 {
     char * * missing_vals = parse_strings(iterator, num_types, err);
     if (err)
         return NULL;
 
-    parsed_t * const parsed_missing_vals = 
-        static_cast<parsed_t *>(PyMem_Malloc(num_types * sizeof(parsed_t)));    
+    _ParsedT * const parsed_missing_vals = 
+        static_cast<_ParsedT *>(PyMem_Malloc(num_types * sizeof(_ParsedT)));    
     if (parsed_missing_vals == NULL) {
         err = true;
         PyErr_NoMemory();
@@ -213,37 +213,37 @@ array_col_reader_new(PyTypeObject * type, PyObject *args, PyObject *keyword_args
 
 static bool
 array_col_reader_copy_int_parsed_col(
-    const parsed_t & t, 
-    const parsed_t & missing_val,
+    const _ParsedT & t, 
+    const _ParsedT & missing_val,
     PyArrayObject * ret, 
     long i)
 {
     bool err;
-    ((long *)ret->data)[i] = parsed_to_long(t.first == t.second? missing_val : t, err);
+    ((long *)ret->data)[i] = _ParsedTo_long(t.first == t.second? missing_val : t, err);
     return !err;
 }
 
 static bool
 array_col_reader_copy_float_parsed_col(
-    const parsed_t & t, 
-    const parsed_t & missing_val,
+    const _ParsedT & t, 
+    const _ParsedT & missing_val,
     PyArrayObject * ret, 
     long i)
 {
     bool err;
-    ((double *)ret->data)[i] = parsed_to_double(t.first == t.second? missing_val : t, err);
+    ((double *)ret->data)[i] = _ParsedTo_double(t.first == t.second? missing_val : t, err);
     return !err;
 }
 
 static void
 array_col_reader_copy_str_parsed_col(
-    const parsed_t & t, 
-    const parsed_t & missing_val,
+    const _ParsedT & t, 
+    const _ParsedT & missing_val,
     PyArrayObject * ret, 
     long i)
 {
     char buf[4];
-    const parsed_t & pt = t.first == t.second? missing_val : t;
+    const _ParsedT & pt = t.first == t.second? missing_val : t;
     sprintf(buf, "%03d", static_cast<int>(distance(pt.first, pt.second)));
     copy(buf, buf + 3, (char *)ret->data + i * max_field_len);
     copy(pt.first, pt.second, (char *)ret->data + i * max_field_len + 3);
@@ -252,7 +252,7 @@ array_col_reader_copy_str_parsed_col(
 static bool
 array_col_reader_copy_parsed_col(
     ArrayColReader * self, 
-    const parsed_t & t, 
+    const _ParsedT & t, 
     long j, 
     long i)
 {
@@ -274,7 +274,7 @@ array_col_reader_copy_parsed_col(
 static bool
 array_col_reader_copy_parsed(
     ArrayColReader * self, 
-    const parsed_t parsed[max_num_cols],
+    const _ParsedT parsed[max_num_cols],
     long i)
 {
     if (self->num_types == 1)
@@ -289,7 +289,7 @@ array_col_reader_copy_parsed(
 static bool
 array_col_reader_copy_parsed_from_inds(
     ArrayColReader * self, 
-    const parsed_t parsed[max_num_cols],
+    const _ParsedT parsed[max_num_cols],
     long i)
 {
     if (self->num_cols == 1)
@@ -302,7 +302,7 @@ array_col_reader_copy_parsed_from_inds(
 }
 
 static bool 
-array_col_reader_parse_line(ArrayColReader * self, parsed_t parsed[max_num_cols])
+array_col_reader_parse_line(ArrayColReader * self, _ParsedT parsed[max_num_cols])
 {
     PyObject * const lineobj = PyIter_Next(self->input_iter); 
     if (lineobj == NULL) 
@@ -343,7 +343,7 @@ extern "C" PyObject *
 array_col_reader_iternext(ArrayColReader * self)
 {
     long i;
-    parsed_t parsed[max_num_cols];
+    _ParsedT parsed[max_num_cols];
     for (i = 0; i  < self->max_elems; ++i) {
     
         if (!array_col_reader_parse_line(self, parsed)) 
