@@ -1,13 +1,13 @@
-#include <cstdlib>
-#include <cstdlib>
-#include <iostream>
-
 #include <Python.h>
 #include <structmember.h>
 
+#include <algorithm>
+#include <cstdlib>
+#include <iostream>
+
 #include "col_reader.hpp"
 #include "_line_to_array.hpp"
-
+    
 using namespace std;
 
 struct ColReader
@@ -87,7 +87,7 @@ col_reader_new(PyTypeObject * type, PyObject *args, PyObject *keyword_args)
         Py_DECREF(self);
         return NULL;
     }
-   
+    
     bool err = false;
     self->input_iter = PyObject_GetIter(iterator);
     _parse_comment(comment, self->has_comment, self->comment);
@@ -108,19 +108,19 @@ col_reader_new(PyTypeObject * type, PyObject *args, PyObject *keyword_args)
 
 
 static PyObject *
-copy_parsed(const parsed_t & t, long num_types, const long * const types, long i)
+copy_parsed(const _ParsedT & t, long num_types, const long * const types, long i)
 {
     if (t.first == t.second)
         Py_RETURN_NONE;
     if (i < num_types && types[i] == _int) 
-        return parsed_to_int(t);
+        return _ParsedTo_int(t);
     if (i >= num_types || types[i] == _float) 
-        return parsed_to_float(t);
-    return parsed_to_string(t);
+        return _ParsedTo_float(t);
+    return _ParsedTo_string(t);
 }
 
 static PyObject *
-col_reader_copy_parsed(ColReader * self, long num_parsed, const parsed_t parsed[max_num_cols])
+col_reader_copy_parsed(ColReader * self, long num_parsed, const _ParsedT parsed[max_num_cols])
 {
     if (num_parsed == 1)
         return copy_parsed(parsed[0], self->num_types, self->types, 0);
@@ -139,7 +139,7 @@ col_reader_copy_parsed(ColReader * self, long num_parsed, const parsed_t parsed[
 }
 
 static PyObject *
-col_reader_copy_parsed_from_inds(ColReader * self, long num_parsed, parsed_t const parsed[max_num_cols])
+col_reader_copy_parsed_from_inds(ColReader * self, long num_parsed, _ParsedT const parsed[max_num_cols])
 {
     if (self->num_cols == 1)
         return copy_parsed(parsed[0], self->num_types, self->types, 0);
@@ -171,12 +171,12 @@ col_reader_iternext(ColReader * self)
     long line_len;
     const char * line = pystring_as_string(lineobj, line_len);
     if (line == NULL || line_len < 0) {
-        PyErr_Format(PyExc_TypeError, "No line, or negative line len %p %ld", line, line_len);
+        PyErr_Format(PyExc_TypeError, "No line or negative line len %p %ld", line, line_len);
         Py_DECREF(lineobj);
         return NULL;
     }
 
-    parsed_t parsed[max_num_cols];
+    _ParsedT parsed[max_num_cols];
     const long num_parsed = self->has_comment?
         _line_to_array(
             self->cols, self->unique_cols, 
@@ -203,26 +203,16 @@ col_reader_iternext(ColReader * self)
 }
 
 extern "C" PyObject *
-col_reader_parse_string(ColReader * self, PyObject *args, PyObject *keyword_args)
+col_reader_parse_string(ColReader * self, PyObject * lineobj)
 {
-    PyObject * lineobj;
-    if (!PyArg_ParseTuple(
-            args, 
-            "O",
-            reinterpret_cast<PyObject **>(&lineobj)) || lineobj == NULL) {
-        PyErr_SetString(PyExc_TypeError, "Failed to parse stuff");
-        return NULL;
-    }
-
     long line_len;
     const char * line = pystring_as_string(lineobj, line_len);
     if (line == NULL || line_len < 0) {
-        PyErr_Format(PyExc_TypeError, "No line, or negative line len %p %ld", line, line_len);
-        Py_DECREF(lineobj);
+        PyErr_Format(PyExc_TypeError, "No line or negative line len %p %ld", line, line_len);
         return NULL;
     }
 
-    parsed_t parsed[max_num_cols];
+    _ParsedT parsed[max_num_cols];
     const long num_parsed = self->has_comment?
         _line_to_array(
             self->cols, self->unique_cols, 
@@ -235,15 +225,12 @@ col_reader_parse_string(ColReader * self, PyObject *args, PyObject *keyword_args
             self->delimit, self->comment, self->skip_init_space,
             line, line_len, parsed);
     if (num_parsed <= 0) {
-        Py_DECREF(lineobj);
         return NULL;
     }
    
     PyObject * const tup = self->copy_cols != NULL?
         col_reader_copy_parsed_from_inds(self, num_parsed, parsed) :
         col_reader_copy_parsed(self, num_parsed, parsed);
-   
-    Py_DECREF(lineobj);
 
     return tup;
 }
@@ -251,12 +238,13 @@ col_reader_parse_string(ColReader * self, PyObject *args, PyObject *keyword_args
 extern "C" int
 col_reader_clear(ColReader * self)
 {
-    Py_CLEAR(self->input_iter);
+    if (self->input_iter != NULL)
+        Py_CLEAR(self->input_iter);
     return 0;
 }
 
 static PyMethodDef col_reader_methods[] = {
-    { "parse_string", (PyCFunction)col_reader_parse_string, METH_VARARGS, "" },
+    { "parse_string", (PyCFunction)col_reader_parse_string, METH_O, "" },
     { NULL, NULL }
 };
 
