@@ -1,9 +1,9 @@
-#include <iostream>
-
 #include <Python.h>
 #include <structmember.h>
 #include <numpy/arrayobject.h>
 
+#include <iostream>
+
 #include "defs.hpp"
 #include "correlator.hpp"
 
@@ -19,52 +19,34 @@ struct Correlator
 
 extern PyTypeObject CorrelatorType;
 
-extern "C" int
-correlator_traverse(Correlator * self, visitproc visit, void *arg)
-{
-    return 0;
-}
-
 extern "C" void
 correlator_dealloc(Correlator * self)
 {
-    PyObject_GC_UnTrack(self);
-
-    PyObject_GC_Del(self);
+    Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
 extern "C" PyObject *
-correlator(PyObject *module, PyObject *args, PyObject *keyword_args)
+correlator_new(PyTypeObject * type, PyObject * args, PyObject * keyword_args)
 {
-    Correlator * const self = PyObject_GC_New(Correlator, &CorrelatorType);
+    Correlator * const self = (Correlator *)type->tp_alloc(type, 0);
     if (self == NULL) {
         PyErr_NoMemory();
         return NULL;
     }
 
     self->sx = self->sy = self->sxx = self->sxy = self->syy = self->n = 0;
-
-    PyObject_GC_Track(self);
+    
     return (PyObject *)self;
 }
 
-extern "C" int
-correlator_clear(Correlator * self)
-{
-    self->sx = self->sy = self->sxx = self->sxy = self->syy = self->n = 0;
-
-    return 0;
-}
-
 extern "C" PyObject *
-correlator_push(PyObject *module, PyObject *args, PyObject *keyword_args)
+correlator_push(Correlator * self, PyObject *args, PyObject *keyword_args)
 {    
-    Correlator * self;
     double x, y;
     if (!PyArg_ParseTuple(
             args, 
-            "Odd",
-            reinterpret_cast<PyObject **>(&self), &x, &y) || self == NULL) {
+            "dd",
+            &x, &y)) {
         PyErr_SetString(PyExc_TypeError, "Failed to parse stuff");
         return NULL;
     }
@@ -80,17 +62,8 @@ correlator_push(PyObject *module, PyObject *args, PyObject *keyword_args)
 }
 
 extern "C" PyObject *
-correlator_corr(PyObject *module, PyObject *args, PyObject *keyword_args)
+correlator_corr(Correlator * self)
 {
-    Correlator * self;
-    if (!PyArg_ParseTuple(
-            args, 
-            "O",
-            reinterpret_cast<PyObject **>(&self)) || self == NULL) {
-        PyErr_SetString(PyExc_TypeError, "Failed to parse stuff");
-        return NULL;
-    }
-    
     const double corr = (self->n * self->sxy - self->sx * self->sy) / 
         sqrt(self->n * self->sxx - self->sx * self->sx) / 
         sqrt(self->n * self->syy - self->sy * self->sy);
@@ -99,6 +72,8 @@ correlator_corr(PyObject *module, PyObject *args, PyObject *keyword_args)
 }
 
 static PyMethodDef correlator_methods[] = {
+    { "push", (PyCFunction)correlator_push, METH_VARARGS, "" },
+    { "corr", (PyCFunction)correlator_corr, METH_NOARGS, "" },
     { NULL}
 };
 
@@ -110,16 +85,16 @@ PyDoc_STRVAR(CorrelatorType_doc, "");
 
 PyTypeObject CorrelatorType = {
     PyVarObject_HEAD_INIT(NULL, 0)
-    "dagpype_c.correlator",               /*tp_name*/
+    "dagpype_c.Correlator",               /*tp_name*/
     sizeof(Correlator),                   /*tp_basicsize*/
     0,                                      /*tp_itemsize*/
     /* methods */
     (destructor)correlator_dealloc,          /*tp_dealloc*/
-    0,                           /*tp_print*/
-    0,                         /*tp_getattr*/
-    0,                         /*tp_setattr*/
-    0,                             /*tp_compare*/
-    0,                            /*tp_repr*/
+    0,                                         /*tp_print*/
+    0,                                         /*tp_getattr*/
+    0,                                         /*tp_setattr*/
+    0,                                          /*tp_compare*/
+    0,                                        /*tp_repr*/
     0,                                      /*tp_as_number*/
     0,                                      /*tp_as_sequence*/
     0,                                      /*tp_as_mapping*/
@@ -129,17 +104,23 @@ PyTypeObject CorrelatorType = {
     0,                                      /*tp_getattro*/
     0,                                      /*tp_setattro*/
     0,                                      /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | 
-    Py_TPFLAGS_HAVE_GC,                     /*tp_flags*/
+    Py_TPFLAGS_DEFAULT ,                     /*tp_flags*/
     CorrelatorType_doc,                     /*tp_doc*/
-    (traverseproc)correlator_traverse,       /*tp_traverse*/
-    (inquiry)correlator_clear,               /*tp_clear*/
+    0,       /*tp_traverse*/
+    0,               /*tp_clear*/
     0,                                      /*tp_richcompare*/
     0,                                      /*tp_weaklistoffset*/
     0,                      /*tp_iter*/
     0,                              /*tp_iternext*/
     correlator_methods,                      /*tp_methods*/
     correlator_memberlist,                   /*tp_members*/
-    0,                                      /*tp_getset*/
+    0,                       /* tp_getset */
+    0,                       /* tp_base */
+    0,                       /* tp_dict */
+    0,                       /* tp_descr_get */
+    0,                       /* tp_descr_set */
+    0,                       /* tp_dictoffset */
+    0,      /* tp_init */
+    0,                         /* tp_alloc */
+    correlator_new,                 /* tp_new */
 };
-
