@@ -43,19 +43,11 @@ static PyMethodDef dagpype_c_methods[] =
 {
     { "line_to_tuple", (PyCFunction)line_to_tuple, METH_VARARGS, NULL},
     { "parser_max_field_len", (PyCFunction)parser_max_field_len, METH_VARARGS, NULL},
-    { "col_reader", (PyCFunction)col_reader, METH_VARARGS, NULL},
-    { "col_reader_parse_string", (PyCFunction)col_reader_parse_string, METH_VARARGS, NULL},
+#ifdef DAGPYPE_USE_AIO
     { "line_writer", (PyCFunction)line_writer, METH_VARARGS, NULL},
     { "line_writer_write", (PyCFunction)line_writer_write, METH_VARARGS, NULL},
     { "line_writer_close", (PyCFunction)line_writer_close, METH_VARARGS, NULL},
-    { "array_col_reader", (PyCFunction)array_col_reader, METH_VARARGS, NULL},
-    { "exp_averager", (PyCFunction)exp_averager, METH_VARARGS, NULL},
-    { "exp_averager_ave", (PyCFunction)exp_averager_ave, METH_VARARGS, NULL},
-    { "enumerator", (PyCFunction)enumerator, METH_VARARGS, NULL},
-    { "enumerator_next", (PyCFunction)enumerator_next, METH_VARARGS, NULL},
-    { "correlator", (PyCFunction)correlator, METH_VARARGS, NULL},
-    { "correlator_push", (PyCFunction)correlator_push, METH_VARARGS, NULL},
-    { "correlator_corr", (PyCFunction)correlator_corr, METH_VARARGS, NULL},
+#endif // #ifdef DAGPYPE_USE_AIO
     { NULL, NULL }
 };
 
@@ -113,6 +105,41 @@ initdagpype_c(void)
     
     import_array();
     
+    if (PyType_Ready(&EnumeratorType) < 0) {
+        Py_DECREF(module);
+        INITERROR;
+    }
+    Py_INCREF(&EnumeratorType);
+    PyModule_AddObject(module, "Enumerator", (PyObject *)&EnumeratorType);
+
+    if (PyType_Ready(&CorrelatorType) < 0) {
+        Py_DECREF(module);
+        INITERROR;
+    }
+    Py_INCREF(&CorrelatorType);
+    PyModule_AddObject(module, "Correlator", (PyObject *)&CorrelatorType);
+
+    if (PyType_Ready(&ExpAveragerType) < 0) {
+        Py_DECREF(module);
+        INITERROR;
+    }
+    Py_INCREF(&CorrelatorType);
+    PyModule_AddObject(module, "ExpAverager", (PyObject *)&ExpAveragerType);
+
+    if (PyType_Ready(&ColReaderType) < 0) {
+        Py_DECREF(module);
+        INITERROR;
+    }
+    Py_INCREF(&ColReaderType);
+    PyModule_AddObject(module, "ColReader", (PyObject *)&ColReaderType);
+
+    if (PyType_Ready(&ArrayColReaderType) < 0) {
+        Py_DECREF(module);
+        INITERROR;
+    }
+    Py_INCREF(&ArrayColReaderType);
+    PyModule_AddObject(module, "ArrayColReader", (PyObject *)&ArrayColReaderType);
+
 #if PY_MAJOR_VERSION >= 3
     return module;
 #endif
