@@ -39,7 +39,8 @@ def chunk_stream_bytes(stream, max_elems = 8192, dtype = numpy.float64, num_cols
     Example:
 
     >>> # Reads from a binary file, and writes the cumulative average to a different one.
-    >>> np.chunk_stream_bytes('foo.dat') | np.cum_ave() | np.chunks_to_stream_bytes('wind_ave.dat')
+    >>> np.chunk_stream_bytes('meteo.dat') | np.cum_ave() | np.chunks_to_stream_bytes('wind_ave.dat')
+    5
     """
     
     @sources
@@ -70,6 +71,7 @@ def chunk_stream_vals(stream,
     comment = None, 
     skip_init_space = True,
     max_elems = 8192):
+
     """
     Streams delimited (e.g., by commas for CSV files, or by tabs for TAB files) values as tuples of
         numpy.arrays.
@@ -100,14 +102,14 @@ def chunk_stream_vals(stream,
 
     >>> # Find the correlation between two named columns.
     >>> np.chunk_stream_vals('meteo.csv', (b'day', b'wind'), (float, float), (0, 0)) | np.corr()    
-    0.74
+    0.019720323758326334
     >>> #Equivalent to:    
     >>> np.chunk_stream_vals('meteo.csv', (b'day', b'wind')) | np.corr()    
-    0.74
+    0.019720323758326334
 
     >>> # Find the correlation between two indexed columns.
-    >>> np.chunk_stream_vals('meteo.csv', (3, 0) | np.corr()    
-    0.23
+    >>> np.chunk_stream_vals('neat_data.csv', (3, 0)) | np.corr()    
+    -0.084075296393769511
     """
 
     def _is_it_t(type_):
