@@ -35,20 +35,20 @@ enum{_int = 0, _float = 1, _str = 2};
 enum{_inds_cols = 0, _names_cols = 1, _all_cols = 2};
 enum{max_num_cols = 1000, max_field_len = 128};
 
-typedef std::pair<const char *, const char *> parsed_t;
+typedef std::pair<const char *, const char *> _ParsedT;
 
 PyObject * 
-parsed_to_string(const parsed_t & t);
+_ParsedTo_string(const _ParsedT & t);
 
 long
-parsed_to_long(const parsed_t & t, bool & err);
+_ParsedTo_long(const _ParsedT & t, bool & err);
 PyObject * 
-parsed_to_int(const parsed_t & t);
+_ParsedTo_int(const _ParsedT & t);
 
 double
-parsed_to_double(const parsed_t & t, bool & err);
+_ParsedTo_double(const _ParsedT & t, bool & err);
 PyObject * 
-parsed_to_float(const parsed_t & t);
+_ParsedTo_float(const _ParsedT & t);
 
 char * 
 pystring_as_string(PyObject * o, long & len);
