@@ -28,7 +28,7 @@ def plot(*args, **kwargs):
                 l.append((yield))
         except GeneratorExit:  
             if len(l) > 0 and isinstance(l[0], tuple):
-                xs = tuple([x[i] for x in l] for i in xrange(len(l[0])))            
+                xs = tuple([x[i] for x in l] for i in range(len(l[0])))            
                 xs = tuple(itertools.chain.from_iterable(
                     itertools.izip_longest(
                         itertools.islice(xs, 0, None, 2),
