@@ -8,7 +8,7 @@ import sys
 def make_text_file(f_name, num_lines, num_chars):
     def _rand_line():
         len_ = int(random.expovariate(1. / num_chars))
-        return ''.join(random.choice(string.letters) for x in range(len_)) + '\n'
+        return ''.join(random.choice(string.ascii_letters) for x in range(len_)) + '\n'
         
     if os.path.exists(f_name):
         os.remove(f_name)
